@@ -1,10 +1,11 @@
 ;; -*- no-byte-compile: t; lexical-binding: nil -*-
-(define-package "metaweblog" "1.1.18"
+(define-package "metaweblog" "20250721.2333"
   "An XML-RPC MetaWeblog and WordPress API client."
-  '((emacs "29.4"))
+  '((emacs   "29.4")
+    (xml-rpc "1.6.15"))
   :url "https://github.com/org2blog/org2blog"
-  :commit "175244a0b7dae8211cf42c17a51c35e9236eda71"
-  :revdesc "v1.1.18-0-g175244a0b7da"
+  :commit "a47847c4231800335786e624025cb58760a4746e"
+  :revdesc "a47847c42318"
   :keywords '("comm")
   :authors '(("Puneeth Chaganti" . "punchagan+org2blog@gmail.com"))
   :maintainers '(("Grant Rettke" . "grant@wisdomandwonder.com")))
