@@ -6,9 +6,9 @@
 
 ;; Author: Puneeth Chaganti <punchagan+org2blog@gmail.com>
 ;; Maintainer: Grant Rettke <grant@wisdomandwonder.com>
-;; Package-Version: 1.1.18
-;; Package-Revision: v1.1.18-0-g175244a0b7da
-;; Package-Requires: ((emacs "29.4"))
+;; Package-Version: 20250721.2333
+;; Package-Revision: a47847c42318
+;; Package-Requires: ((emacs "29.4") (xml-rpc "1.6.15"))
 ;; Keywords: comm
 ;; Homepage: https://github.com/org2blog/org2blog
 
@@ -27,9 +27,13 @@
 
 ;;; Commentary:
 
+;; A portion of the code in this file is based on blog.el posted to
+;; http://www.mail-archive.com/gnu-emacs-sources@gnu.org/msg01576.html
+;; copyrighted by Ashish Shukla.
+
 ;; This API operates against WordPress using both the
 ;; XML-RPC MetaWeblog API specification
-;; https://codex.wordpress.org/XML-RPC_MetaWeblog_API#metaWeblog.getRecentPosts
+;; https://codex.wordpress.org/XML-RPC_MetaWeblog_API
 ;; and the XML-RPC WordPress API
 ;; https://codex.wordpress.org/XML-RPC_WordPress_API
 
@@ -40,10 +44,6 @@
 ;; including them in line at the end of the docstring only to satisfy
 ;; the byte-compiler.
 
-;; A portion of the code in this file is based on blog.el posted to
-;; http://www.mail-archive.com/gnu-emacs-sources@gnu.org/msg01576.html
-;; copyrighted by Ashish Shukla.
-
 ;;; Code:
 
 ;;; Require
@@ -151,53 +151,54 @@ BLOG-XMLRPC USER-NAME PASSWORD BLOG-ID"
       `((methodCall
          nil
          (methodName nil "metaWeblog.newPost")
-         (params nil
-                 (param nil (value nil (string nil ,blog-id)))
-                 (param nil (value nil (string nil ,user-name)))
-                 (param nil (value nil (string nil ,password)))
-                 (param nil (value nil
-                                   (struct
-                                    nil
-                                    (member nil
-                                            (name nil "title")
-                                            (value nil ,post-title))
-                                    (member nil
-                                            (name nil "description")
-                                            (value nil ,post-description))
-                                    (member nil
-                                            (name nil "mt_excerpt")
-                                            (value nil ,post-excerpt))
-                                    (member nil
-                                            (name nil "wp_slug")
-                                            (value nil ,post-permalink))
-                                    (member nil
-                                            (name nil "dateCreated")
-                                            (dateTime.iso8601 nil ,post-date))
-                                    ,(when post-tags
-                                       `(member nil
-                                                (name nil "mt_keywords")
-                                                (value nil
-                                                       (array
-                                                        nil
-                                                        ,(append
-                                                          '(data nil)
-                                                          (mapcar
-                                                           (lambda(f)
-                                                             `(value nil (string nil ,f)))
-                                                           post-tags))))))
-                                    ,(when post-categories
-                                       `(member nil
-                                                (name nil "categories")
-                                                (value nil
-                                                       (array
-                                                        nil
-                                                        ,(append
-                                                          '(data nil)
-                                                          (mapcar
-                                                           (lambda(f)
-                                                             `(value nil (string nil ,f)))
-                                                           post-categories)))))))))
-                 (param nil (value nil (boolean nil ,(if publish "1" "0")))))))))))
+         (params
+          nil
+          (param nil (value nil (string nil ,blog-id)))
+          (param nil (value nil (string nil ,user-name)))
+          (param nil (value nil (string nil ,password)))
+          (param
+           nil
+           (value
+            nil
+            (struct
+             nil
+             (member nil
+                     (name nil "title")
+                     (value nil (string nil ,post-title)))
+             (member nil
+                     (name nil "description")
+                     (value nil (string nil ,post-description)))
+             (member nil
+                     (name nil "mt_excerpt")
+                     (value nil (string nil ,post-excerpt)))
+             (member nil
+                     (name nil "dateCreated")
+                     (value nil (dateTime.iso8601 nil ,post-date)))
+             ,(when post-tags
+                `(member nil
+                         (name nil "mt_keywords")
+                         (value nil
+                                (array
+                                 nil
+                                 ,(append
+                                   '(data nil)
+                                   (mapcar
+                                    (lambda(f)
+                                      `(value nil (string nil ,f)))
+                                    post-tags))))))
+             ,(when post-categories
+                `(member nil
+                         (name nil "categories")
+                         (value nil
+                                (array
+                                 nil
+                                 ,(append
+                                   '(data nil)
+                                   (mapcar
+                                    (lambda(f)
+                                      `(value nil (string nil ,f)))
+                                    post-categories)))))))))
+          (param nil (value nil (boolean nil ,(if publish "1" "0")))))))))))
 
 (defun metaweblog-wp-new-page
     (blog-xmlrpc user-name password blog-id content publish)
@@ -227,56 +228,57 @@ BLOG-XMLRPC USER-NAME PASSWORD BLOG-ID"
       `((methodCall
          nil
          (methodName nil "wp.newPage")
-         (params nil
-                 (param nil (value nil (string nil ,blog-id)))
-                 (param nil (value nil (string nil ,user-name)))
-                 (param nil (value nil (string nil ,password)))
-                 (param nil (value nil
-                                   (struct
-                                    nil
-                                    (member nil
-                                            (name nil "title")
-                                            (value nil ,post-title))
-                                    (member nil
-                                            (name nil "description")
-                                            (value nil ,post-description))
-                                    (member nil
-                                            (name nil "mt_excerpt")
-                                            (value nil ,post-excerpt))
-                                    (member nil
-                                            (name nil "wp_slug")
-                                            (value nil ,post-permalink))
-                                    (member nil
-                                            (name nil "wp_page_parent_id")
-                                            (value nil ,post-parent))
-                                    (member nil
-                                            (name nil "dateCreated")
-                                            (dateTime.iso8601 nil ,post-date))
-                                    ,(when post-tags
-                                       `(member nil
-                                                (name nil "mt_keywords")
-                                                (value nil
-                                                       (array
-                                                        nil
-                                                        ,(append
-                                                          '(data nil)
-                                                          (mapcar
-                                                           (lambda(f)
-                                                             `(value nil (string nil ,f)))
-                                                           post-tags))))))
-                                    ,(when post-categories
-                                       `(member nil
-                                                (name nil "categories")
-                                                (value nil
-                                                       (array
-                                                        nil
-                                                        ,(append
-                                                          '(data nil)
-                                                          (mapcar
-                                                           (lambda(f)
-                                                             `(value nil (string nil ,f)))
-                                                           post-categories)))))))))
-                 (param nil (value nil (boolean nil ,(if publish "1" "0")))))))))))
+         (params
+          nil
+          (param nil (value nil (string nil ,blog-id)))
+          (param nil (value nil (string nil ,user-name)))
+          (param nil (value nil (string nil ,password)))
+          (param
+           nil
+           (value
+            nil
+            (struct
+             nil
+             (member nil
+                     (name nil "title")
+                     (value nil (string nil ,post-title)))
+             (member nil
+                     (name nil "description")
+                     (value nil (string nil ,post-description)))
+             (member nil
+                     (name nil "mt_excerpt")
+                     (value nil (string nil ,post-excerpt)))
+             (member nil
+                     (name nil "wp_page_parent_id")
+                     (value nil (string nil ,post-parent)))
+             (member nil
+                     (name nil "dateCreated")
+                     (value nil (dateTime.iso8601 nil ,post-date)))
+             ,(when post-tags
+                `(member nil
+                         (name nil "mt_keywords")
+                         (value nil
+                                (array
+                                 nil
+                                 ,(append
+                                   '(data nil)
+                                   (mapcar
+                                    (lambda(f)
+                                      `(value nil (string nil ,f)))
+                                    post-tags))))))
+             ,(when post-categories
+                `(member nil
+                         (name nil "categories")
+                         (value nil
+                                (array
+                                 nil
+                                 ,(append
+                                   '(data nil)
+                                   (mapcar
+                                    (lambda(f)
+                                      `(value nil (string nil ,f)))
+                                    post-categories)))))))))
+          (param nil (value nil (boolean nil ,(if publish "1" "0")))))))))))
 
 (defun metaweblog-wp-edit-page
     (blog-xmlrpc user-name password blog-id page-id content publish)
@@ -307,57 +309,58 @@ BLOG-XMLRPC USER-NAME PASSWORD BLOG-ID"
       `((methodCall
          nil
          (methodName nil "wp.editPage")
-         (params nil
-                 (param nil (value nil (string nil ,blog-id)))
-                 (param nil (value nil (string nil ,page-id)))
-                 (param nil (value nil (string nil ,user-name)))
-                 (param nil (value nil (string nil ,password)))
-                 (param nil (value nil
-                                   (struct
-                                    nil
-                                    (member nil
-                                            (name nil "title")
-                                            (value nil ,post-title))
-                                    (member nil
-                                            (name nil "description")
-                                            (value nil ,post-description))
-                                    (member nil
-                                            (name nil "mt_excerpt")
-                                            (value nil ,post-excerpt))
-                                    (member nil
-                                            (name nil "wp_slug")
-                                            (value nil ,post-permalink))
-                                    (member nil
-                                            (name nil "wp_page_parent_id")
-                                            (value nil ,post-parent))
-                                    (member nil
-                                            (name nil "dateCreated")
-                                            (dateTime.iso8601 nil ,post-date))
-                                    ,(when post-tags
-                                       `(member nil
-                                                (name nil "mt_keywords")
-                                                (value nil
-                                                       (array
-                                                        nil
-                                                        ,(append
-                                                          '(data nil)
-                                                          (mapcar
-                                                           (lambda(f)
-                                                             `(value nil (string nil ,f)))
-                                                           post-tags))))))
-                                    ,(when post-categories
-                                       `(member nil
-                                                (name nil "categories")
-                                                (value nil
-                                                       (array
-                                                        nil
-                                                        ,(append
-                                                          '(data nil)
-                                                          (mapcar
-                                                           (lambda(f)
-                                                             `(value nil (string nil ,f)))
-                                                           post-categories)))))))))
-                 (param nil (value nil (boolean nil ,(if publish "1" "0")))))))))))
+         (params
+          nil
+          (param nil (value nil (string nil ,blog-id)))
+          (param nil (value nil (string nil ,page-id)))
+          (param nil (value nil (string nil ,user-name)))
+          (param nil (value nil (string nil ,password)))
+          (param
+           nil
+           (value
+            nil
+            (struct
+             nil
+             (member nil
+                     (name nil "title")
+                     (value nil (string nil ,post-title)))
+             (member nil
+                     (name nil "description")
+                     (value nil (string nil ,post-description)))
+             (member nil
+                     (name nil "mt_excerpt")
+                     (value nil (string nil ,post-excerpt)))
+             (member nil
+                     (name nil "wp_page_parent_id")
+                     (value nil (string nil ,post-parent)))
+             (member nil
+                     (name nil "dateCreated")
+                     (value nil (dateTime.iso8601 nil ,post-date)))
+             ,(when post-tags
+                `(member nil
+                         (name nil "mt_keywords")
+                         (value nil
+                                (array
+                                 nil
+                                 ,(append
+                                   '(data nil)
+                                   (mapcar
+                                    (lambda(f)
+                                      `(value nil (string nil ,f)))
+                                    post-tags))))))
+             ,(when post-categories
+                `(member nil
+                         (name nil "categories")
+                         (value nil
+                                (array
+                                 nil
+                                 ,(append
+                                   '(data nil)
+                                   (mapcar
+                                    (lambda(f)
+                                      `(value nil (string nil ,f)))
+                                    post-categories)))))))))
+          (param nil (value nil (boolean nil ,(if publish "1" "0")))))))))))
 
 (defun metaweblog-edit-post
     (blog-xmlrpc user-name password post-id content publish)
@@ -387,53 +390,54 @@ BLOG-XMLRPC USER-NAME PASSWORD BLOG-ID"
       `((methodCall
          nil
          (methodName nil "metaWeblog.editPost")
-         (params nil
-                 (param nil (value nil (string nil ,post-id)))
-                 (param nil (value nil (string nil ,user-name)))
-                 (param nil (value nil (string nil ,password)))
-                 (param nil (value nil
-                                   (struct
-                                    nil
-                                    (member nil
-                                            (name nil "title")
-                                            (value nil ,post-title))
-                                    (member nil
-                                            (name nil "description")
-                                            (value nil ,post-description))
-                                    (member nil
-                                            (name nil "mt_excerpt")
-                                            (value nil ,post-excerpt))
-                                    (member nil
-                                            (name nil "wp_slug")
-                                            (value nil ,post-permalink))
-                                    (member nil
-                                            (name nil "dateCreated")
-                                            (dateTime.iso8601 nil ,post-date))
-                                    ,(when post-tags
-                                       `(member nil
-                                                (name nil "mt_keywords")
-                                                (value nil
-                                                       (array
-                                                        nil
-                                                        ,(append
-                                                          '(data nil)
-                                                          (mapcar
-                                                           (lambda(f)
-                                                             `(value nil (string nil ,f)))
-                                                           post-tags))))))
-                                    ,(when post-categories
-                                       `(member nil
-                                                (name nil "categories")
-                                                (value nil
-                                                       (array
-                                                        nil
-                                                        ,(append
-                                                          '(data nil)
-                                                          (mapcar
-                                                           (lambda(f)
-                                                             `(value nil (string nil ,f)))
-                                                           post-categories)))))))))
-                 (param nil (value nil (boolean nil ,(if publish "1" "0")))))))))))
+         (params
+          nil
+          (param nil (value nil (string nil ,post-id)))
+          (param nil (value nil (string nil ,user-name)))
+          (param nil (value nil (string nil ,password)))
+          (param
+           nil
+           (value
+            nil
+            (struct
+             nil
+             (member nil
+                     (name nil "title")
+                     (value nil (string nil ,post-title)))
+             (member nil
+                     (name nil "description")
+                     (value nil (string nil ,post-description)))
+             (member nil
+                     (name nil "mt_excerpt")
+                     (value nil (string nil ,post-excerpt)))             
+             (member nil
+                     (name nil "dateCreated")
+                     (value nil (dateTime.iso8601 nil ,post-date)))
+             ,(when post-tags
+                `(member nil
+                         (name nil "mt_keywords")
+                         (value nil
+                                (array
+                                 nil
+                                 ,(append
+                                   '(data nil)
+                                   (mapcar
+                                    (lambda(f)
+                                      `(value nil (string nil ,f)))
+                                    post-tags))))))
+             ,(when post-categories
+                `(member nil
+                         (name nil "categories")
+                         (value nil
+                                (array
+                                 nil
+                                 ,(append
+                                   '(data nil)
+                                   (mapcar
+                                    (lambda(f)
+                                      `(value nil (string nil ,f)))
+                                    post-categories)))))))))
+          (param nil (value nil (boolean nil ,(if publish "1" "0")))))))))))
 
 (defun metaweblog-get-post (blog-xmlrpc user-name password post-id)
   "Retrieve a post POST-ID.
@@ -484,27 +488,43 @@ BLOG-XMLRPC USER-NAME PASSWORD BLOG-ID"
                        number-of-posts))
 
 (defun metaweblog-get-file-properties (file)
-  "Gets the properties of a file FILE.
+  "Convert FILE to its constituent base-64 encoded data.
 
 Returns an assoc list with
 name - file name
 bits - data of the file as a base64 encoded string
-type - mimetype of file deduced from extension.
-
-BLOG-XMLRPC USER-NAME PASSWORD BLOG-ID"
-  (let* (base64-str type name file-props)
-    (save-excursion
-      (save-restriction
-        (with-current-buffer (find-file-noselect file nil t)
-          (fundamental-mode)
-          (setq name (file-name-nondirectory file))
-          (setq base64-str (base64-encode-string (encode-coding-string (buffer-string) 'binary)))
-          (setq type (mailcap-extension-to-mime (or (file-name-extension file) "")))
-          (kill-buffer)
-          (setq file-props `(("name" . ,name)
-                             ("bits" . ,base64-str)
-                             ("type" . ,type))))))
-    file-props))
+type - mimetype of file deduced from extension."
+  (catch 'return
+    (condition-case err
+        (progn
+          (unless (file-readable-p file)
+            (let ((msg (format "`%s' is not readable." file)))
+              (display-warning 'metaweblog msg :error)
+              (throw 'return nil)))
+          (with-temp-buffer
+            (set-buffer-multibyte nil)
+            (insert-file-contents-literally file)
+            (unless (> (length (buffer-string)) 0)
+              (let ((msg (format "`%s' is readable but empty." file)))
+                (display-warning 'metaweblog msg :error)
+                (throw 'return nil)))
+            (let* ((name (file-name-nondirectory file))
+                   (bits (base64-encode-string (buffer-string) t))
+                   (type (mailcap-extension-to-mime
+                          (or (file-name-extension file) "")))
+                   (file-props (list (cons "name" name)
+                                     (cons "bits" bits)
+                                     (cons "type" type))))
+              file-props)))
+      (file-error
+       (let ((msg (format "File error: %s" (error-message-string err))))
+         (display-warning 'metaweblog msg :error)
+         (throw 'return nil)))
+      (wrong-type-argument
+       (let ((msg (format "Wrong type argument: %s"
+                          (error-message-string err))))
+         (display-warning 'metaweblog msg :error)
+         (throw 'return nil))))))
 
 (defun metaweblog-upload-file (blog-xmlrpc user-name password blog-id file)
   "Upload a media file FILE.
